@@ -21,15 +21,13 @@
   @NOTATION@
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
-#include "gnome-i18nP.h"
-
-#include "gnome-exec.h"
-#include "gnome-util.h"
-#include "gnome-i18n.h"
-#include "gnome-gconfP.h"
-#include "gnome-init.h"
+#include <libgnome/gnome-exec.h>
+#include <libgnome/gnome-util.h>
+#include <libgnome/gnome-i18n.h>
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -40,7 +38,9 @@
 #include <string.h>
 #include <signal.h>
 
-#include <gconf/gconf-client.h>
+#include <libgnome/gnome-init.h>
+#include <bonobo/bonobo-property-bag-client.h>
+#include <bonobo/bonobo-exception.h>
 
 #include <popt.h>
 
@@ -57,15 +57,15 @@ set_cloexec (gint fd)
 
 /**
  * gnome_execute_async_with_env_fds:
- * @dir: Directory in which child should be executed, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @argc: Number of arguments
  * @argv: Argument vector to exec child
  * @envc: Number of environment slots
  * @envv: Environment vector
- * @close_fds: If %TRUE will close all fds but 0,1, and 2
+ * @close_fds: If TRUE will close all fds but 0,1, and 2
  * 
- * Description:  Like gnome_execute_async_with_env() but has a flag to
+ * Description:  Like #gnome_execute_async_with_env() but has a flag to
  * decide whether or not to close fd's
  * 
  * Returns: the process id, or %-1 on error.
@@ -138,7 +138,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
 
       if(dir) chdir(dir);
 
-      cpargv = g_alloca((argc + 1) * sizeof(char *));
+      cpargv = alloca((argc + 1) * sizeof(char *));
       memcpy(cpargv, argv, argc * sizeof(char *));
       cpargv[argc] = NULL;
 
@@ -185,8 +185,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
   res = read (parent_comm_pipes[0], &child_pid, sizeof(child_pid));
   if (res != sizeof(child_pid))
     {
-      g_message("res is %ld instead of %d",
-		(long)res, (int)sizeof(child_pid));
+      g_message("res is %d instead of %d", res, (int)sizeof(child_pid));
       child_pid = -1; /* really weird things happened */
     }
   else if (read (parent_comm_pipes[0], &child_errno, sizeof(child_errno))
@@ -210,7 +209,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
 
 /**
  * gnome_execute_async_with_env:
- * @dir: Directory in which child should be executed, or NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @argc: Number of arguments
  * @argv: Argument vector to exec child
@@ -218,7 +217,7 @@ gnome_execute_async_with_env_fds (const char *dir, int argc,
  * @envv: Environment vector
  * 
  * Description: This function forks and executes some program in the
- * background.  On error, returns %-1; in this case, #errno should hold a useful
+ * background.  On error, returns %-1; in this case, errno should hold a useful
  * value.  Searches the path to find the child.  Environment settings in @envv
  * are added to the existing environment -- they do not completely replace it.
  * This function closes all fds besides 0, 1, and 2 for the child
@@ -235,7 +234,7 @@ gnome_execute_async_with_env (const char *dir, int argc, char * const argv[],
 
 /**
  * gnome_execute_async:
- * @dir: Directory in which child should be executesd, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @argc: Number of arguments
  * @argv: Argument vector to exec child
@@ -253,13 +252,13 @@ gnome_execute_async (const char *dir, int argc, char * const argv[])
 
 /**
  * gnome_execute_async_fds:
- * @dir: Directory in which child should be executed, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @argc: Number of arguments
  * @argv: Argument vector to exec child
- * @close_fds: If %TRUE, will close all but file descriptors 0, 1 and 2.
+ * @close_fds: 
  *
- * Description: Like gnome_execute_async_with_env_fds(), but doesn't add
+ * Description: Like #gnome_execute_async_with_env_fds, but doesn't add
  * anything to child's environment.
  * 
  * Returns: process id of child, or %-1 on error.
@@ -274,12 +273,12 @@ gnome_execute_async_fds (const char *dir, int argc,
 
 /**
  * gnome_execute_shell_fds:
- * @dir: Directory in which child should be executed, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @commandline: Shell command to execute
  * @close_fds: Like close_fds in gnome_execute_async_with_env_fds()
  *
- * Description: Like gnome_execute_async_with_env_fds(), but uses the user's
+ * Description: Like #gnome_execute_async_with_env_fds, but uses the user's
  * shell to run the desired program.  Note that the pid of the shell is
  * returned, not the pid of the user's program.
  * 
@@ -311,11 +310,11 @@ gnome_execute_shell_fds (const char *dir, const char *commandline,
 
 /**
  * gnome_execute_shell:
- * @dir: Directory in which child should be executed, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @commandline: Shell command to execute
  * 
- * Description: Like gnome_execute_async_with_env(), but uses the user's shell
+ * Description: Like #gnome_execute_async_with_env, but uses the user's shell
  * to run the desired program.  Note that the pid of the shell is returned, not
  * the pid of the user's program.
  * 
@@ -332,14 +331,14 @@ gnome_execute_shell (const char *dir, const char *commandline)
  * @argc: a pointer to the vector size
  * @argv: a pointer to the vector
  *
- * Description:  Prepends a terminal (either the one configured as default in
- * the user's GNOME setup, or one of the common xterm emulators) to the passed
- * in vector, modifying it in the process.  The vector should be allocated with
- * #g_malloc, as this will #g_free the original vector.  Also all elements must
- * have been allocated separately.  That is the standard glib/GNOME way of
- * doing vectors however.  If the integer that @argc points to is negative, the
- * size will first be computed.  Also note that passing in pointers to a vector
- * that is empty, will just create a new vector for you.
+ * Description:  Prepends the selected terminal to the
+ * passed in vector, modifying it in the process.  The vector should
+ * be allocated with g_malloc, as this will g_free the original vector.
+ * Also all elements must have been allocated separately.  That is the
+ * standard glib/gnome way of doing vectors however.  If the integer
+ * that @argc points to is negative, the size will first be computed.
+ * Also note that passing in pointers to a vector that is empty, will
+ * just create a new vector for you.
  **/
 void
 gnome_prepend_terminal_to_vector (int *argc, char ***argv)
@@ -348,9 +347,10 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
         int real_argc;
         int i, j;
 	char **term_argv = NULL;
+	const char **temp_argv = NULL;
 	int term_argc = 0;
-	GConfClient *client;
 
+	Bonobo_ConfigDatabase db;
 	gchar *terminal = NULL;
 
 	char **the_argv;
@@ -371,34 +371,12 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 		*argc = i;
 	}
 
-	/* init our gconf stuff if necessary */
-	gnome_gconf_lazy_init ();
-
-	client = gconf_client_get_default ();
-	terminal = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec", NULL);
-	g_object_unref (G_OBJECT (client));
-	
+	db = gnome_get_config_database ();
+	terminal = bonobo_pbclient_get_string (db, "/Gnome/Applications/Terminal", NULL);
+	g_message (G_STRLOC ": |%s|", terminal);
 	if (terminal) {
-		gchar *exec_flag;
-		exec_flag = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec_arg", NULL);
-
-		if (exec_flag == NULL) {
-			term_argc = 1;
-			term_argv = g_new0 (char *, 2);
-			term_argv[0] = terminal;
-			term_argv[1] = NULL;
-		} else {
-			term_argc = 2;
-			term_argv = g_new0 (char *, 3);
-			term_argv[0] = terminal;
-			term_argv[1] = exec_flag;
-			term_argv[2] = NULL;
-		}
-#if 0
 	    poptParseArgvString (terminal, &term_argc, &temp_argv);
 	    term_argv = g_strdupv ((gchar **) temp_argv);
-	    g_free (terminal);
-#endif
 	}
 
 	if (term_argv == NULL) {
@@ -407,23 +385,23 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 		term_argc = 2;
 		term_argv = g_new0 (char *, 3);
 
-		check = g_find_program_in_path ("gnome-terminal");
+		check = gnome_is_program_in_path("gnome-terminal");
 		if (check != NULL) {
 			term_argv[0] = check;
 			/* Note that gnome-terminal takes -x and
-			 * as -e in gnome-terminal is broken we use that. */
+			 * as -e in gnome-terminal is broken */
 			term_argv[1] = g_strdup ("-x");
 		} else {
 			if (check == NULL)
-				check = g_find_program_in_path ("nxterm");
+				check = gnome_is_program_in_path("nxterm");
 			if (check == NULL)
-				check = g_find_program_in_path ("color-xterm");
+				check = gnome_is_program_in_path("color-xterm");
 			if (check == NULL)
-				check = g_find_program_in_path ("rxvt");
+				check = gnome_is_program_in_path("rxvt");
 			if (check == NULL)
-				check = g_find_program_in_path ("xterm");
+				check = gnome_is_program_in_path("xterm");
 			if (check == NULL)
-				check = g_find_program_in_path ("dtterm");
+				check = gnome_is_program_in_path("dtterm");
 			if (check == NULL) {
 				g_warning (_("Cannot find a terminal, using "
 					     "xterm, even if it may not work"));
@@ -452,16 +430,17 @@ gnome_prepend_terminal_to_vector (int *argc, char ***argv)
 	/* we use g_free here as we sucked all the inner strings
 	 * out from it into real_argv */
 	g_free (term_argv);
+	g_free (terminal);
 }
 
 /**
  * gnome_execute_terminal_shell_fds:
- * @dir: Directory in which child should be executed, or %NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @commandline: Shell command to execute
  * @close_fds: Like close_fds in gnome_execute_async_with_env_fds()
  *
- * Description:  Like gnome_execute_shell_fds(), except that it runs the
+ * Description:  Like #gnome_execute_shell_fds, except that it runs the
  * terminal as well.  Note that the pid of the terminal is
  * returned, not the pid of the user's program.
  * If commandline is %NULL, just the shell is run.
@@ -506,7 +485,7 @@ gnome_execute_terminal_shell_fds (const char *dir, const char *commandline,
 
 /**
  * gnome_execute_terminal_shell:
- * @dir: Directory in which child should be executed, or NULL for current
+ * @dir: Directory in which child should be execd, or NULL for current
  *       directory
  * @commandline: Shell command to execute
  * 
