@@ -34,9 +34,8 @@
 #include <glib.h>
 #include <popt.h>
 #include <stdarg.h>
-#include <errno.h>
 
-#include <glib-object.h>
+#include <gobject/gobject.h>
 
 
 G_BEGIN_DECLS
@@ -51,39 +50,14 @@ typedef struct _GnomeProgram          GnomeProgram;
 typedef struct _GnomeProgramPrivate   GnomeProgramPrivate;
 typedef struct _GnomeProgramClass     GnomeProgramClass;
 
-/**
- * GnomeFileDomain:
- * @GNOME_FILE_DOMAIN_UNKNOWN: An unknown file domain (should never be used).
- * @GNOME_FILE_DOMAIN_LIBDIR: Libraries in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_DATADIR: Data files in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_SOUND: Sound files in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_PIXMAP: Pixmap files in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_CONFIG: Config files in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_HELP: Help files in the main GNOME installation.
- * @GNOME_FILE_DOMAIN_APP_LIBDIR: Application specific libraries.
- * @GNOME_FILE_DOMAIN_APP_DATADIR: Application specific data files.
- * @GNOME_FILE_DOMAIN_APP_SOUND: Application specific sound files.
- * @GNOME_FILE_DOMAIN_APP_PIXMAP: Application specific pixmap files.
- * @GNOME_FILE_DOMAIN_APP_CONFIG: Application specific config files.
- * @GNOME_FILE_DOMAIN_APP_HELP: Application specific help files.
- **/
 typedef enum {
     GNOME_FILE_DOMAIN_UNKNOWN = 0,
-
-    /* Gnome installed files */
     GNOME_FILE_DOMAIN_LIBDIR,
     GNOME_FILE_DOMAIN_DATADIR,
     GNOME_FILE_DOMAIN_SOUND,
     GNOME_FILE_DOMAIN_PIXMAP,
     GNOME_FILE_DOMAIN_CONFIG,
     GNOME_FILE_DOMAIN_HELP,
-
-    /* Application files */
-    GNOME_FILE_DOMAIN_APP_LIBDIR,
-    GNOME_FILE_DOMAIN_APP_DATADIR,
-    GNOME_FILE_DOMAIN_APP_SOUND,
-    GNOME_FILE_DOMAIN_APP_PIXMAP,
-    GNOME_FILE_DOMAIN_APP_CONFIG,
     GNOME_FILE_DOMAIN_APP_HELP
 } GnomeFileDomain;
 
@@ -97,10 +71,6 @@ struct _GnomeProgram
 struct _GnomeProgramClass
 {
     GObjectClass object_class;
-
-    /* we may want to add stuff in the future */
-    gpointer padding1;
-    gpointer padding2;
 };
 
 GType
@@ -109,14 +79,14 @@ gnome_program_get_type                  (void);
 GnomeProgram *
 gnome_program_get                       (void);
 
-const char *
+const char*
 gnome_program_get_human_readable_name   (GnomeProgram *program);
 
 const char *
-gnome_program_get_app_id                (GnomeProgram *program);
+gnome_program_get_name                  (GnomeProgram *program);
 
 const char *
-gnome_program_get_app_version           (GnomeProgram *program);
+gnome_program_get_version               (GnomeProgram *program);
 
 gchar *
 gnome_program_locate_file               (GnomeProgram    *program,
@@ -125,19 +95,17 @@ gnome_program_locate_file               (GnomeProgram    *program,
 					 gboolean         only_if_exists,
 					 GSList         **ret_locations);
 
-#define GNOME_PARAM_NONE                NULL
+#define GNOME_PARAM_MODULE_INFO         "module-info"
+#define GNOME_PARAM_MODULES             "modules"
 #define GNOME_PARAM_POPT_TABLE          "popt-table"
 #define GNOME_PARAM_POPT_FLAGS          "popt-flags"
 #define GNOME_PARAM_POPT_CONTEXT        "popt-context"
 #define GNOME_PARAM_CREATE_DIRECTORIES  "create-directories"
+#define GNOME_PARAM_SOUND_DRIVER	"sound-driver"
 #define GNOME_PARAM_ENABLE_SOUND        "enable-sound"
-#define GNOME_PARAM_ESPEAKER            "espeaker"
+#define GNOME_PARAM_FILE_LOCATOR        "file-locator"
 #define GNOME_PARAM_APP_ID              "app-id"
 #define GNOME_PARAM_APP_VERSION         "app-version"
-#define GNOME_PARAM_GNOME_PREFIX        "gnome-prefix"
-#define GNOME_PARAM_GNOME_SYSCONFDIR    "gnome-sysconfdir"
-#define GNOME_PARAM_GNOME_DATADIR       "gnome-datadir"
-#define GNOME_PARAM_GNOME_LIBDIR        "gnome-libdir"
 #define GNOME_PARAM_APP_PREFIX          "app-prefix"
 #define GNOME_PARAM_APP_SYSCONFDIR      "app-sysconfdir"
 #define GNOME_PARAM_APP_DATADIR         "app-datadir"
@@ -154,14 +122,9 @@ gnome_module_info_get_type              (void);
 typedef struct _GnomeModuleInfo GnomeModuleInfo;
 typedef struct _GnomeModuleRequirement GnomeModuleRequirement;
 
-/**
- * GnomeModuleRequirement:
- * @required_version: The version required by the parent module.
- * @module_info: The required module's information.
- */
 struct _GnomeModuleRequirement {
     const char *required_version;
-    const GnomeModuleInfo *module_info;
+    GnomeModuleInfo *module_info;
 };
 
 typedef void (*GnomeModuleInitHook) (const GnomeModuleInfo *mod_info);
@@ -170,28 +133,8 @@ typedef void (*GnomeModuleClassInitHook) (GnomeProgramClass *klass,
 typedef void (*GnomeModuleHook) (GnomeProgram *program,
 				 GnomeModuleInfo *mod_info);
 
-/**
- * GnomeModuleInfo:
- * @name: The module name.
- * @version: The module's version string.
- * @description: A string describing the module (can be %NULL).
- * @requirements: A pointer to a module that is required by this module. If no
- * requirements, this should be %NULL.
- * @instance_init:
- * @pre_args_parse:
- * @post_args_parse:
- * @options:
- * @init_pass: A function which is run before the preinit function to allow the
- * module to register other modules as needed. The module cannot assume its
- * required modules are initialized (they aren't).
- * @class_init:
- * @expansion1: Unused.
- * @expansion2: Unused.
- */
 struct _GnomeModuleInfo {
-    const char *name;
-    const char *version;
-    const char *description;
+    const char *name, *version, *description;
     GnomeModuleRequirement *requirements; /* last element has NULL version */
 
     GnomeModuleHook instance_init;
@@ -199,12 +142,15 @@ struct _GnomeModuleInfo {
 
     struct poptOption *options;
 
-    GnomeModuleInitHook init_pass;
+    GnomeModuleInitHook init_pass; /* This gets run before the preinit
+				      function to allow the module to
+				      register other modules as needed. The
+				      module cannot assume its required
+				      modules are initialized (they aren't). */
 
     GnomeModuleClassInitHook class_init;
 
-    const char *opt_prefix;
-    gpointer    expansion1;
+    gpointer expansion1, expansion2;
 };
 
 /* This function should be called before gnomelib_preinit() - it's an
@@ -242,14 +188,6 @@ gnome_program_parse_args (GnomeProgram *program);
 void
 gnome_program_postinit (GnomeProgram *program);
 
-/* If you have your auto* define PREFIX, SYSCONFDIR, DATADIR and LIBDIR,
- * Use this macro in your init code. */
-#define GNOME_PROGRAM_STANDARD_PROPERTIES \
-	GNOME_PARAM_APP_PREFIX, PREFIX,		\
-	GNOME_PARAM_APP_SYSCONFDIR, SYSCONFDIR,	\
-	GNOME_PARAM_APP_DATADIR, DATADIR,	\
-	GNOME_PARAM_APP_LIBDIR, LIBDIR
-
 /* These are convenience functions that calls gnomelib_preinit(...), have
    popt parse all args, and then call gnomelib_postinit() */
 GnomeProgram *
@@ -265,6 +203,9 @@ gnome_program_initv (GType type,
 		     int argc, char **argv,
 		     const char *first_property_name, va_list args);
 
-G_END_DECLS
+/* Some systems, like Red Hat 4.0, define these but don't declare
+   them.  Hopefully it is safe to always declare them here.  */
+extern char *program_invocation_short_name;
+extern char *program_invocation_name;
 
-#endif /* GNOME_PROGRAM_H */
+#endif
